@@ -1,5 +1,5 @@
 package CPAN::Releases::Latest;
-$CPAN::Releases::Latest::VERSION = '0.06';
+$CPAN::Releases::Latest::VERSION = '0.07';
 use 5.006;
 use Moo;
 use File::HomeDir;
@@ -345,7 +345,7 @@ ever made to CPAN.
 
 =head1 REPOSITORY
 
-L<https://github.com/neilbowers/CPAN-Releases-Latest>
+L<https://github.com/neilb/CPAN-Releases-Latest>
 
 =head1 AUTHOR
 
